==> openshift-client-4.9.2-sources.jar: io/fabric8/openshift/client/handlers/ClusterVersionHandler.java <==
  
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterVersionOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.ClusterVersion;
import io.fabric8.openshift.api.model.ClusterVersionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterVersionHandler implements ResourceHandler<ClusterVersion, ClusterVersionBuilder> {

  @Override
  public String getKind() {
    return ClusterVersion.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public ClusterVersion create(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ClusterVersion replace(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ClusterVersion reload(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterVersionBuilder edit(ClusterVersion item) {
    return new ClusterVersionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, Boolean cascading, ClusterVersion item) {
    if (cascading) {
      return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).cascading(true).delete();
    } else {
      return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).delete(item);
    }
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterVersion item, Watcher<ClusterVersion> watcher) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterVersion item, String resourceVersion, Watcher<ClusterVersion> watcher) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public ClusterVersion waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterVersion item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterVersion waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterVersion item, Predicate<ClusterVersion> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-4.10.0-sources.jar: io/fabric8/openshift/client/handlers/ClusterVersionHandler.java <==
  
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterVersionOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.openshift.api.model.ClusterVersion;
import io.fabric8.openshift.api.model.ClusterVersionBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterVersionHandler implements ResourceHandler<ClusterVersion, ClusterVersionBuilder> {

  @Override
  public String getKind() {
    return ClusterVersion.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public ClusterVersion create(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ClusterVersion replace(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ClusterVersion reload(OkHttpClient client, Config config, String namespace, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterVersionBuilder edit(ClusterVersion item) {
    return new ClusterVersionBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, ClusterVersion item) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterVersion item, Watcher<ClusterVersion> watcher) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterVersion item, String resourceVersion, Watcher<ClusterVersion> watcher) {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public ClusterVersion waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterVersion item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterVersion waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterVersion item, Predicate<ClusterVersion> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterVersionOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
